@@ -143,9 +143,9 @@ def get_disabled_quotas(f, request):
 
 
 @wrap(quotas.tenant_quota_usages)
-def tenant_quota_usages(f, request, tenant_id=None):
+def tenant_quota_usages(f, request, tenant_id=None, targets=None):
 
-    usages = f(request, tenant_id)
+    usages = f(request, tenant_id, targets)
 
     if 'shares' not in _get_manila_disabled_quotas(request):
         shares = manila.share_list(request)
@@ -380,6 +380,7 @@ def get_context_data(self, **kwargs):
     for t in types:
         if t[0] in self.usage.limits and t[1] in self.usage.limits:
             context['charts'].append({
+                'type': t[0],
                 'name': t[2],
                 'used': self.usage.limits[t[0]],
                 'max': self.usage.limits[t[1]],
