@@ -16,14 +16,14 @@ import copy
 import ddt
 from django.core.urlresolvers import reverse
 import mock
-
-from manila_ui.api import manila as api_manila
-from manila_ui.tests.dashboards.project.shares import test_data
-from manila_ui.tests import helpers as test
-
 from openstack_dashboard.api import neutron
 
-SHARE_INDEX_URL = reverse('horizon:project:shares:index')
+from manila_ui.api import manila as api_manila
+from manila_ui.dashboards.project.shares.replicas import tables as r_tables
+from manila_ui.tests.dashboards.project import test_data
+from manila_ui.tests import helpers as test
+
+INDEX_URL = reverse('horizon:project:shares:index')
 
 
 class FakeAZ(object):
@@ -152,7 +152,7 @@ class ReplicasTests(test.TestCase):
         res = self.client.get(url)
 
         self.assertEqual(302, res.status_code)
-        self.assertRedirectsNoFollow(res, SHARE_INDEX_URL)
+        self.assertRedirectsNoFollow(res, INDEX_URL)
         self.assertTemplateNotUsed(res, "project/shares/replicas/detail.html")
         api_manila.share_replica_get.assert_called_once_with(
             mock.ANY, self.share_replica.id)
@@ -186,7 +186,7 @@ class ReplicasTests(test.TestCase):
         res = self.client.get(url)
 
         self.assertEqual(302, res.status_code)
-        self.assertRedirectsNoFollow(res, SHARE_INDEX_URL)
+        self.assertRedirectsNoFollow(res, INDEX_URL)
         self.assertTemplateNotUsed(
             res, "project/shares/replicas/manage_replicas.html")
         api_manila.share_replica_list.assert_called_with(
@@ -311,3 +311,18 @@ class ReplicasTests(test.TestCase):
 
         self.assertRedirectsNoFollow(
             res, reverse("horizon:project:shares:index"))
+
+    def test_replicas_table(self):
+        replicas_table = r_tables.ReplicasTable(self.request)
+        counter = 0
+        columns = ['created_at', 'updated_at']
+        for column in replicas_table.get_columns():
+            if column.name in columns:
+                self.assertEqual(1, len(column.filters))
+                self.assertEqual(
+                    column.filters[0], r_tables.filters.parse_isotime)
+                counter += 1
+                columns.remove(column.name)
+        self.assertEqual(
+            2, counter,
+            "The following columns are missing: %s." % ', '.join(columns))
